@@ -55,17 +55,17 @@ class SMBShareSelectDialog(KDialogBase):
         self.treeview.header().hide()
         self.treeview.setRootIsDecorated(True)
         
-        self.connect(self.treeview,SIGNAL("expanded(TQListViewItem *)"),self.slotNodeExpanded)
-        self.connect(self.treeview,SIGNAL("selectionChanged(TQListViewItem *)"),self.slotNodeSelected)
-        self.connect(self.treeview,SIGNAL("clicked(TQListViewItem *)"),self.slotClicked)
+        self.connect(self.treeview,TQ_SIGNAL("expanded(TQListViewItem *)"),self.slotNodeExpanded)
+        self.connect(self.treeview,TQ_SIGNAL("selectionChanged(TQListViewItem *)"),self.slotNodeSelected)
+        self.connect(self.treeview,TQ_SIGNAL("clicked(TQListViewItem *)"),self.slotClicked)
         self.dirlister = KDirLister()
         self.dirlister.setDirOnlyMode(True)
         self.dirlister.setAutoUpdate(False)
         self.dirlister.setAutoErrorHandlingEnabled(True,self)
-        self.connect(self.dirlister,SIGNAL("newItems(const KFileItemList &)"),self.slotNewItems)
-        self.connect(self.dirlister,SIGNAL("completed()"),self.slotDirListCompleted)
-        self.connect(self.dirlister,SIGNAL("canceled()"),self.slotDirListCanceled)
-        self.connect(self.dirlister,SIGNAL("redirection(const KURL &,const KURL &)"),self.slotDirListRedirection)
+        self.connect(self.dirlister,TQ_SIGNAL("newItems(const KFileItemList &)"),self.slotNewItems)
+        self.connect(self.dirlister,TQ_SIGNAL("completed()"),self.slotDirListCompleted)
+        self.connect(self.dirlister,TQ_SIGNAL("canceled()"),self.slotDirListCanceled)
+        self.connect(self.dirlister,TQ_SIGNAL("redirection(const KURL &,const KURL &)"),self.slotDirListRedirection)
         self.enableButtonOK(False)
 
         # The "Connect as" part
@@ -87,18 +87,18 @@ class SMBShareSelectDialog(KDialogBase):
         tmplabel = TQLabel(widget)
         tmplabel.setText(i18n("Guest"))
         grid.addWidget(tmplabel,1,2)
-        self.connect(self.guestradio,SIGNAL("stateChanged(int)"),self.slotGuestRadioClicked)
+        self.connect(self.guestradio,TQ_SIGNAL("stateChanged(int)"),self.slotGuestRadioClicked)
         
         self.userradio = TQRadioButton(widget)
         grid.addWidget(self.userradio,2,1)
         tmplabel = TQLabel(widget)
         tmplabel.setText(i18n("Username:"))
         grid.addWidget(tmplabel,2,2)
-        self.connect(self.userradio,SIGNAL("stateChanged(int)"),self.slotUserRadioClicked)
+        self.connect(self.userradio,TQ_SIGNAL("stateChanged(int)"),self.slotUserRadioClicked)
         
         self.usernameedit = KLineEdit(widget)
         grid.addWidget(self.usernameedit,2,3)
-        self.connect(self.usernameedit,SIGNAL("textChanged(const TQString &)"),self.slotUsernameChanged)
+        self.connect(self.usernameedit,TQ_SIGNAL("textChanged(const TQString &)"),self.slotUsernameChanged)
         
         tmplabel = TQLabel(widget)
         tmplabel.setText(i18n("Password:"))
@@ -109,7 +109,7 @@ class SMBShareSelectDialog(KDialogBase):
         
         self.reconnectbutton = KPushButton(i18n("Reconnect now"),widget)
         grid.addMultiCellWidget(self.reconnectbutton,4,4,1,3)
-        self.connect(self.reconnectbutton,SIGNAL("clicked()"),self.slotReconnectClicked)
+        self.connect(self.reconnectbutton,TQ_SIGNAL("clicked()"),self.slotReconnectClicked)
         
         self.dirlistertimer = None
         
