@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 ###########################################################################
 # fuser.py - description                                                  #
 # ------------------------------                                          #
@@ -133,12 +133,12 @@ class FUser(FUserUI):
             application.
             """)) % (self.device,self.device,self.device))
 
-        self.connect(self.cancelbutton,SIGNAL("clicked()"),self.slotCancelButtonClicked)
-        self.connect(self.killbutton,SIGNAL("clicked()"),self.slotKillButtonClicked)
-        self.connect(self.killallbutton,SIGNAL("clicked()"),self.slotKillallButtonClicked)
-        self.connect(self.refreshbutton,SIGNAL("clicked()"),self.refreshProcesslist)
-        self.connect(self.processlist,SIGNAL("selectionChanged()"),self.slotSelectionChanged)
-        self.connect(self.umountbutton,SIGNAL("clicked()"),self.slotUmountButtonClicked)
+        self.connect(self.cancelbutton,TQ_SIGNAL("clicked()"),self.slotCancelButtonClicked)
+        self.connect(self.killbutton,TQ_SIGNAL("clicked()"),self.slotKillButtonClicked)
+        self.connect(self.killallbutton,TQ_SIGNAL("clicked()"),self.slotKillallButtonClicked)
+        self.connect(self.refreshbutton,TQ_SIGNAL("clicked()"),self.refreshProcesslist)
+        self.connect(self.processlist,TQ_SIGNAL("selectionChanged()"),self.slotSelectionChanged)
+        self.connect(self.umountbutton,TQ_SIGNAL("clicked()"),self.slotUmountButtonClicked)
 
         # TODO: Make optionsbutton resize dialog if processframe is hidden, hide Optionsbutton until then.
         self.optionsbutton.hide()
