@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: UTF-8 -*-
 ###########################################################################
 # serviceconfig.py - description                                          #
@@ -1001,7 +1001,7 @@ class SysVInitApp(programbase):
 
         hb.setStretchFactor(self.runlevelcombo,0)
 
-        self.connect(self.runlevelcombo, SIGNAL("activated(int)"), self.slotRunLevelChanged)
+        self.connect(self.runlevelcombo, TQ_SIGNAL("activated(int)"), self.slotRunLevelChanged)
 
         widget = TQWidget(hb)
         hb.setStretchFactor(widget,1)
@@ -1012,7 +1012,7 @@ class SysVInitApp(programbase):
         self.servicelistview.addColumn(i18n("Status"))
         self.servicelistview.setAllColumnsShowFocus(True)
         self.servicelistview.setSelectionMode(TQListView.Single)
-        self.connect(self.servicelistview, SIGNAL("selectionChanged(TQListViewItem *)"), self.slotListClicked)
+        self.connect(self.servicelistview, TQ_SIGNAL("selectionChanged(TQListViewItem *)"), self.slotListClicked)
 
         # Right hand side of the dialog.
         vb = TQVBox(tophb)
@@ -1030,7 +1030,7 @@ class SysVInitApp(programbase):
         self.descriptiontextedit.setReadOnly(True)
         self.startatbootcheckbox = TQCheckBox(i18n("Start during boot"),vb2)
         vb2.setStretchFactor(self.startatbootcheckbox,0)
-        self.connect(self.startatbootcheckbox, SIGNAL("toggled(bool)"), self.slotBootChanged)
+        self.connect(self.startatbootcheckbox, TQ_SIGNAL("toggled(bool)"), self.slotBootChanged)
 
         label = TQLabel(i18n("Status:"),vb2)
         vb2.setStretchFactor(label,0)
@@ -1043,24 +1043,24 @@ class SysVInitApp(programbase):
         vb2.setStretchFactor(hb2,0)
         self.startbutton = TQPushButton(i18n("Start"),hb2)
         hb2.setStretchFactor(self.startbutton,1)
-        self.connect(self.startbutton, SIGNAL("clicked()"), self.slotStartButton)
+        self.connect(self.startbutton, TQ_SIGNAL("clicked()"), self.slotStartButton)
         self.stopbutton = TQPushButton(i18n("Stop"),hb2)
         hb2.setStretchFactor(self.stopbutton,1)
-        self.connect(self.stopbutton, SIGNAL("clicked()"), self.slotStopButton)
+        self.connect(self.stopbutton, TQ_SIGNAL("clicked()"), self.slotStopButton)
         self.restartbutton = TQPushButton(i18n("Restart"),hb2)
         hb2.setStretchFactor(self.restartbutton,1)
-        self.connect(self.restartbutton, SIGNAL("clicked()"), self.slotRestartButton)
+        self.connect(self.restartbutton, TQ_SIGNAL("clicked()"), self.slotRestartButton)
 
         if DISTRO == "Gentoo":
             # Gentoo Linux gets an extra button.
             self.zapbutton = TQPushButton(i18n("Zap"),hb2)
             hb2.setStretchFactor(self.zapbutton,1)
-            self.connect(self.zapbutton, SIGNAL("clicked()"), self.slotZapButton)
+            self.connect(self.zapbutton, TQ_SIGNAL("clicked()"), self.slotZapButton)
 
         if not isroot:
             self.disableStuff()
         else:
-            self.connect(self.servicelistview, SIGNAL("contextMenu(TDEListView*,TQListViewItem*,const TQPoint&)"), 
+            self.connect(self.servicelistview, TQ_SIGNAL("contextMenu(TDEListView*,TQListViewItem*,const TQPoint&)"), 
                     self.slotServiceContextMenu)
 
         self.__fillListView(self.currentrunlevel)
@@ -1395,9 +1395,9 @@ class CommandRunner(KDialogBase):
 
         self.kid = TQProcess()
         self.kid.setCommunication(TQProcess.Stdout|TQProcess.Stderr)
-        self.connect(self.kid,SIGNAL("processExited()"),self.slotProcessExited)
-        self.connect(self.kid,SIGNAL("readyReadStdout()"),self.slotReadyReadStdout)
-        self.connect(self.kid,SIGNAL("readyReadStderr()"),self.slotReadyReadStderr)
+        self.connect(self.kid,TQ_SIGNAL("processExited()"),self.slotProcessExited)
+        self.connect(self.kid,TQ_SIGNAL("readyReadStdout()"),self.slotReadyReadStdout)
+        self.connect(self.kid,TQ_SIGNAL("readyReadStderr()"),self.slotReadyReadStderr)
 
     ########################################################################
     def run(self,argslist):
@@ -1437,9 +1437,9 @@ class CommandRunner(KDialogBase):
     def slotReadyReadStdout(self):
         # Remove the colors used by some programs.
         # FIXME: this probably isn't neccessary anymore.
-        uncolor = lambda text: re.compile('\\x1b\[[0-9]+;01m').sub("", \
-          re.compile('\\x1b\[0m').sub("", re.compile('\\033\[1;[0-9]+m').sub("", \
-          re.compile('\\033\[0m').sub("", text))))
+        uncolor = lambda text: re.compile('\\x1b\\[[0-9]+;01m').sub("", \
+          re.compile('\\x1b\\[0m').sub("", re.compile('\\033\\[1;[0-9]+m').sub("", \
+          re.compile('\\033\\[0m').sub("", text))))
         self.output += uncolor(str(self.kid.readStdout()))
         self.outputtextview.setText(self.output)
         self.outputtextview.ensureVisible(0,self.outputtextview.contentsHeight())
